@@ -1,19 +1,5 @@
 var NAVTREEINDEX27 =
 {
-"a01974.html#aff18ae3eec14a6a9d2b3ad3ae1645ced":[5,0,0,0,0,5,9,11],
-"a01974.html#aff18ae3eec14a6a9d2b3ad3ae1645ced":[6,0,0,0,0,0,9,11],
-"a01978.html":[5,0,0,0,0,5,1],
-"a01978.html":[6,0,0,0,0,0,1],
-"a02539.html":[0],
-"a02539.html#Calc":[0,14],
-"a02539.html#Draw":[0,16],
-"a02539.html#Filter":[0,21],
-"a02539.html#LanguageTool":[0,32],
-"a02539.html#LibreOfficeKit":[0,33],
-"a02539.html#Math":[0,35],
-"a02539.html#SAL":[0,0],
-"a02539.html#URE":[0,49],
-"a02539.html#VCL":[0,52],
 "a02539.html#Writer":[0,54],
 "a02539.html#avmedia":[0,61],
 "a02539.html#basctl":[0,1],
@@ -249,5 +235,19 @@ var NAVTREEINDEX27 =
 "globals_defs_o.html":[7,1,6,2],
 "globals_defs_p.html":[7,1,6,3],
 "globals_defs_r.html":[7,1,6,4],
-"globals_defs_s.html":[7,1,6,5]
+"globals_defs_s.html":[7,1,6,5],
+"globals_defs_u.html":[7,1,6,6],
+"globals_enum.html":[7,1,4],
+"globals_eval.html":[7,1,5],
+"globals_eval.html":[7,1,5,0],
+"globals_eval_r.html":[7,1,5,1],
+"globals_eval_s.html":[7,1,5,2],
+"globals_eval_t.html":[7,1,5,3],
+"globals_func.html":[7,1,1],
+"globals_func.html":[7,1,1,0],
+"globals_func_g.html":[7,1,1,1],
+"globals_func_o.html":[7,1,1,2],
+"globals_func_r.html":[7,1,1,3],
+"globals_func_s.html":[7,1,1,4],
+"globals_func_t.html":[7,1,1,5]
 };
