@@ -1,6 +1,6 @@
 var interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2 =
 [
-    [ "XPropertySet", "interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::beans::XPropertySet", "interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
     [ "XPresentation", "interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html#ade1da748982465f3c5bad1cf29f0b276", null ],
     [ "getController", "interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html#adee6830554dc58b7af571f728a62a3b5", null ],
     [ "isRunning", "interfacecom_1_1sun_1_1star_1_1presentation_1_1XPresentation2.html#a876c0699cfeae70f84fc508a4b05b6c0", null ],
