@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
     [ "XColumnsSupplier", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a92868318efdc74df5cf74c939aa50e9b", null ],
     [ "XDataDescriptorFactory", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a165621d8c4d1f58bd9578b5afb525aac", null ],
     [ "Catalog", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a93c5cd015ea94a5e7423c31fe6b4ffbd", null ],
